pub struct TextBox { /* private fields */ }Implementations
Sourceimpl TextBox
impl TextBox
pub fn new() -> Self
pub fn value(self, value: impl Into<String>) -> Self
pub fn text(&self) -> &str
pub fn placeholder(self, placeholder: impl Into<SmolStr>) -> Self
pub fn max_length(self, max_length: usize) -> Self
pub fn read_only(self, value: bool) -> Self
pub fn on_change(self, f: impl FnMut(&str, &mut EventCtx) + 'static) -> Self
pub fn on_submit(self, f: impl FnMut(&str, &mut EventCtx) + 'static) -> Self
Sourceimpl TextBox
impl TextBox
pub fn on_click(self, f: impl FnMut(&mut EventCtx) + 'static) -> Self
pub fn on_hover(self, f: impl FnMut(bool, &mut EventCtx) + 'static) -> Self
pub fn on_mouse_enter(self, f: impl FnMut(&mut EventCtx) + 'static) -> Self
pub fn on_mouse_leave(self, f: impl FnMut(&mut EventCtx) + 'static) -> Self
pub fn on_mouse_input( self, f: impl FnMut(ElementState, MouseButton, &mut EventCtx) + 'static, ) -> Self
pub fn on_key( self, f: impl FnMut(&KeyboardEvent, &mut EventCtx) + 'static, ) -> Self
pub fn window_drag_region(self, value: bool) -> Self
Sourceimpl TextBox
impl TextBox
Sourcepub fn key(self, key: impl Into<SmolStr>) -> Self
pub fn key(self, key: impl Into<SmolStr>) -> Self
Stable identity among siblings, kept across rebuilds even when this widget moves position (reorder, insert, remove). Use for list items instead of relying on array index.
pub fn font(self, font: impl Into<SmolStr>) -> Self
pub fn hover_background<M>( self, background: impl IntoThemed<Background, M>, ) -> Self
pub fn pressed_background<M>( self, background: impl IntoThemed<Background, M>, ) -> Self
pub fn disabled_background<M>( self, background: impl IntoThemed<Background, M>, ) -> Self
pub fn enabled(self, enabled: bool) -> Self
Sourceimpl TextBox
impl TextBox
pub fn hover_style( self, build: impl FnOnce(StylePatch, &Theme) -> StylePatch, ) -> Self
pub fn pressed_style( self, build: impl FnOnce(StylePatch, &Theme) -> StylePatch, ) -> Self
pub fn focus_style( self, build: impl FnOnce(StylePatch, &Theme) -> StylePatch, ) -> Self
pub fn disabled_style( self, build: impl FnOnce(StylePatch, &Theme) -> StylePatch, ) -> Self
pub fn focused_hover_style( self, build: impl FnOnce(StylePatch, &Theme) -> StylePatch, ) -> Self